PCB Environment: Data Fields - Variables

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all variables with links to the structures/unions they belong to:

### - c -

- C : CloneEnv, UIActions
- can_route : dsn::Placement
- Chan : NavPixel< chan_t >
- Class : Policy::CommonParams
- Clearance : NavSpacings, UserAgent
- clearance : dsn::Connection, dsn::Net, dsn::Pin, dsn::Placement, dsn::Structure
- compound : dsn::Pin
- coms : PCBItemSets
- Connect : UserAgent
- Connections : NetTopology
- connections : dsn::Net
- cons : PCBItemSets
- copper_index : dsn::Layer
- copper_layers : dsn::Structure
- CostMap : UserAgent
- Count : GridDirection
- CYAN : Color